package com.flossom.system.service.impl;

import java.util.List;

import com.flossom.common.core.domain.entity.IntegralClock;
import com.flossom.common.core.enums.ClockStatus;
import com.flossom.common.core.mapper.IntegralClockMapper;
import com.flossom.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.flossom.system.service.IIntegralClockService;

/**
 * 打卡奖励积分Service业务层处理
 *
 * @author flossom
 * @date 2024-01-25
 */
@Service
public class IntegralClockServiceImpl implements IIntegralClockService
{
    @Autowired
    private IntegralClockMapper integralClockMapper;

    /**
     * 查询打卡奖励积分
     *
     * @param id 打卡奖励积分主键
     * @return 打卡奖励积分
     */
    @Override
    public IntegralClock selectIntegralClockById(Long id)
    {
        return integralClockMapper.selectIntegralClockById(id);
    }

    /**
     * 查询打卡奖励积分列表
     *
     * @param integralClock 打卡奖励积分
     * @return 打卡奖励积分
     */
    @Override
    public List<IntegralClock> selectIntegralClockList(IntegralClock integralClock)
    {
        return integralClockMapper.selectIntegralClockList(integralClock);
    }

    /**
     * 新增打卡奖励积分
     *
     * @param integralClock 打卡奖励积分
     * @return 结果
     */
    @Override
    public int insertIntegralClock(IntegralClock integralClock)
    {
        integralClock.setCreateTime(DateUtils.getNowDate());
        return integralClockMapper.insertIntegralClock(integralClock);
    }

    /**
     * 修改打卡奖励积分
     *
     * @param integralClock 打卡奖励积分
     * @return 结果
     */
    @Override
    public int updateIntegralClock(IntegralClock integralClock)
    {
        integralClock.setUpdateTime(DateUtils.getNowDate());
//        if (ClockStatus.DISABLE.getCode() == integralClock.getIsExtraClock().intValue()) {
//            // 当操作关闭的时候，把其他数据关联数据清空
//            integralClock.setExtraClockCredit();
//        }
        return integralClockMapper.updateIntegralClock(integralClock);
    }

    /**
     * 批量删除打卡奖励积分
     *
     * @param ids 需要删除的打卡奖励积分主键
     * @return 结果
     */
    @Override
    public int deleteIntegralClockByIds(Long[] ids)
    {
        return integralClockMapper.deleteIntegralClockByIds(ids);
    }

    /**
     * 删除打卡奖励积分信息
     *
     * @param id 打卡奖励积分主键
     * @return 结果
     */
    @Override
    public int deleteIntegralClockById(Long id)
    {
        return integralClockMapper.deleteIntegralClockById(id);
    }
}
